@@ -10,6 +10,8 @@
 #include <unicode/uclean.h>
 #include "tepl-abstract-factory.h"
 #include "tepl-metadata-manager.h"
+#include "tepl-prefs-dialog.h"
+#include "tepl-settings.h"
 
 static gchar *
 get_locale_directory (void)
@@ -95,8 +97,10 @@ tepl_finalize (void)
 
 	if (!done)
 	{
-		_tepl_metadata_manager_unref_singleton ();
 		_tepl_abstract_factory_unref_singleton ();
+		_tepl_metadata_manager_unref_singleton ();
+		_tepl_prefs_dialog_unref_singleton ();
+		_tepl_settings_unref_singleton ();
 
 		/* Since Tepl depends on Amtk and GtkSourceView, it's better to
 		 * first finalize Tepl stuff and then finalize the underlying
