@@ -12,14 +12,18 @@
  * @Short_description: A simple #GtkSourceStyleSchemeChooser
  *
  * #TeplStyleSchemeChooserWidget is a simple implementation of the
- * #GtkSourceStyleSchemeChooser interface. It already contains a
- * #GtkScrolledWindow internally.
+ * #GtkSourceStyleSchemeChooser interface.
  *
- * Additional features compared to #GtkSourceStyleSchemeChooserWidget:
- * - There is an additional convenience property:
- *   #TeplStyleSchemeChooserWidget:tepl-style-scheme-id.
- * - When the #GtkWidget::map signal is emitted, #TeplStyleSchemeChooserWidget
- *   scrolls to the selected row.
+ * It shows a list with the name and description of each #GtkSourceStyleScheme,
+ * taken from the default #GtkSourceStyleSchemeManager (as returned by
+ * gtk_source_style_scheme_manager_get_default()).
+ *
+ * #TeplStyleSchemeChooserWidget contains a #GtkScrolledWindow internally. When
+ * the #GtkWidget::map signal is emitted, it scrolls to the selected row (useful
+ * when the list is long).
+ *
+ * There is also an additional convenience property:
+ * #TeplStyleSchemeChooserWidget:tepl-style-scheme-id.
  */
 
 struct _TeplStyleSchemeChooserWidgetPrivate
@@ -291,25 +295,19 @@ static void
 populate_list_box (TeplStyleSchemeChooserWidget *chooser)
 {
 	GtkSourceStyleSchemeManager *manager;
-	const gchar * const *scheme_ids;
-	gint i;
+	GList *schemes;
+	GList *l;
 
 	manager = gtk_source_style_scheme_manager_get_default ();
-	scheme_ids = gtk_source_style_scheme_manager_get_scheme_ids (manager);
+	schemes = gtk_source_style_scheme_manager_get_schemes (manager);
 
-	if (scheme_ids == NULL)
+	for (l = schemes; l != NULL; l = l->next)
 	{
-		return;
-	}
-
-	for (i = 0; scheme_ids[i] != NULL; i++)
-	{
-		const gchar *cur_scheme_id = scheme_ids[i];
-		GtkSourceStyleScheme *style_scheme;
-
-		style_scheme = gtk_source_style_scheme_manager_get_scheme (manager, cur_scheme_id);
+		GtkSourceStyleScheme *style_scheme = GTK_SOURCE_STYLE_SCHEME (l->data);
 		append_style_scheme_to_list_box (chooser, style_scheme);
 	}
+
+	g_list_free (schemes);
 }
 
 static void
@@ -327,9 +325,8 @@ list_box_selected_rows_changed_cb (GtkListBox                   *list_box,
 }
 
 static void
-style_scheme_manager_notify_scheme_ids_cb (GtkSourceStyleSchemeManager  *manager,
-					   GParamSpec                   *pspec,
-					   TeplStyleSchemeChooserWidget *chooser)
+style_scheme_manager_changed_cb (GtkSourceStyleSchemeManager  *manager,
+				 TeplStyleSchemeChooserWidget *chooser)
 {
 	gchar *style_scheme_id;
 
@@ -367,8 +364,8 @@ listen_to_scheme_manager_changes (TeplStyleSchemeChooserWidget *chooser)
 	manager = gtk_source_style_scheme_manager_get_default ();
 
 	g_signal_connect_object (manager,
-				 "notify::scheme-ids",
-				 G_CALLBACK (style_scheme_manager_notify_scheme_ids_cb),
+				 "changed",
+				 G_CALLBACK (style_scheme_manager_changed_cb),
 				 chooser,
 				 0);
 }
