@@ -1,20 +1,5 @@
-/*
- * This file is part of Tepl, a text editor library.
- *
- * Copyright 2017 - Sébastien Wilmet <swilmet@gnome.org>
- *
- * Tepl is free software; you can redistribute it and/or modify it under
- * the terms of the GNU Lesser General Public License as published by the
- * Free Software Foundation; either version 2.1 of the License, or (at your
- * option) any later version.
- *
- * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
- * License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+/* SPDX-FileCopyrightText: 2017 - Sébastien Wilmet <swilmet@gnome.org>
+ * SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #ifndef TEPL_TAB_GROUP_H
@@ -76,23 +61,32 @@ struct _TeplTabGroupInterface
 						 TeplTab      *tab);
 };
 
+_TEPL_EXTERN
 GType		tepl_tab_group_get_type			(void);
 
+_TEPL_EXTERN
 GList *		tepl_tab_group_get_tabs			(TeplTabGroup *tab_group);
 
+_TEPL_EXTERN
 GList *		tepl_tab_group_get_views		(TeplTabGroup *tab_group);
 
+_TEPL_EXTERN
 GList *		tepl_tab_group_get_buffers		(TeplTabGroup *tab_group);
 
+_TEPL_EXTERN
 TeplTab *	tepl_tab_group_get_active_tab		(TeplTabGroup *tab_group);
 
+_TEPL_EXTERN
 void		tepl_tab_group_set_active_tab		(TeplTabGroup *tab_group,
 							 TeplTab      *tab);
 
+_TEPL_EXTERN
 TeplView *	tepl_tab_group_get_active_view		(TeplTabGroup *tab_group);
 
+_TEPL_EXTERN
 TeplBuffer *	tepl_tab_group_get_active_buffer	(TeplTabGroup *tab_group);
 
+_TEPL_EXTERN
 void		tepl_tab_group_append_tab		(TeplTabGroup *tab_group,
 							 TeplTab      *tab,
 							 gboolean      jump_to);
