@@ -1206,6 +1206,24 @@ tepl_utils_get_titled_component (const gchar *title,
 	return GTK_WIDGET (vgrid);
 }
 
+/**
+ * tepl_utils_setup_statusbar:
+ * @statusbar: a #GtkStatusbar.
+ *
+ * To better configure a #GtkStatusbar (to make it smaller).
+ *
+ * Since: 6.8
+ */
+void
+tepl_utils_setup_statusbar (GtkStatusbar *statusbar)
+{
+	g_return_if_fail (GTK_IS_STATUSBAR (statusbar));
+
+	g_object_set (statusbar,
+		      "margin", 0,
+		      NULL);
+}
+
 /**
  * tepl_utils_binding_transform_func_smart_bool:
  * @binding: a #GBinding.
